{{ cookiecutter.project_name }}
{{ cookiecutter.project_name|count * "=" }}

{{ cookiecutter.summary }}

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`{{ cookiecutter.project_name }}` was written by `{{ cookiecutter.author }} <{{ cookiecutter.email }}>`_.
